describe('Decoding', function(){
    const magnetURI = require('../lib');
    const _ = require('underscore');

    const objectEquality = function(f, s){
        if(typeof f == 'object' && typeof s == 'object'){
            return _.isEqual(f, s);
        }
    };

    beforeEach(function(){
        jasmine.addCustomEqualityTester(objectEquality);
    });

    it('should handle indexed parameters', function(){
        const uri1 = 'magnet:?xt.1=urn:sha1:YNCKHTQCWBTRNJIV4WNAE52SJUQCZO5C&xt.2=urn:sha1:TXGCZQTH26NL6OUQAJJPFALHG2LTGBC7';
        const obj1 = {
          'xt':[
              'urn:sha1:YNCKHTQCWBTRNJIV4WNAE52SJUQCZO5C',
              'urn:sha1:TXGCZQTH26NL6OUQAJJPFALHG2LTGBC7'
          ]
        };
        expect(magnetURI.decode(uri1)).toEqual(obj1);
    });

    it('should decode more complex magnet uris', function(){
        const uri1 = 'magnet:?xt=urn:ed2k:354B15E68FB8F36D7CD88FF94116CDC1&xt=urn:tree:tiger:7N5OAMRNGMSSEUE3ORHOKWN4WWIQ5X4EBOOTLJY&xt=urn:btih:QHQXPYWMACKDWKP47RRVIV7VOURXFE5Q&xl=10826029&dn=mediawiki-1.15.1.tar.gz&tr=udp%3A%2F%2Ftracker.openbittorrent.com%3A80%2Fannounce&as=http%3A%2F%2Fdownload.wikimedia.org%2Fmediawiki%2F1.15%2Fmediawiki-1.15.1.tar.gz&xs=http%3A%2F%2Fcache.example.org%2FXRX2PEFXOOEJFRVUCX6HMZMKS5TWG4K5&xs=dchub%3A%2F%2Fexample.org';
        const obj1 = {
            'xt':
                [ 'urn:ed2k:354B15E68FB8F36D7CD88FF94116CDC1',
                    'urn:tree:tiger:7N5OAMRNGMSSEUE3ORHOKWN4WWIQ5X4EBOOTLJY',
                    'urn:btih:QHQXPYWMACKDWKP47RRVIV7VOURXFE5Q'
                ],
            'xl': '10826029',
            'dn': 'mediawiki-1.15.1.tar.gz',
            'tr': 'udp://tracker.openbittorrent.com:80/announce',
            'as': 'http://download.wikimedia.org/mediawiki/1.15/mediawiki-1.15.1.tar.gz',
            'xs':
                [ 'http://cache.example.org/XRX2PEFXOOEJFRVUCX6HMZMKS5TWG4K5',
                    'dchub://example.org'
                ]
        };
        expect(magnetURI.decode(uri1)).toEqual(obj1);
    });
});


