import {isArray} from './utils';

export default (function(){
    /**
     * @name decode
     * @desc Decodes a Magnet URI and returns an object of all its parameters.
     * @param magnet_uri {string}
     * @returns {Object}
     */
    function decode(magnet_uri){
        const params = magnet_uri.split('magnet:?')[1];
        return get_params(params);
    }
    /**
     * @name getParams
     * @desc The magnet uri is formatted in the same way as query params.
     * @param params {string}
     * @returns {Object}
     * @private
     */
    function get_params(params){
        const params_obj = {}, re = /([^&?]+)=([^&?]*)/g
        let match;
        while(match = re.exec(params)){
            /* Standard allows for the parameters to be used by appending .1, .2, ... to the parameter name (https://en.wikipedia.org/wiki/Magnet_URI_scheme)*/
            const key = match[1].split('.')[0];
            let value = match[2];
            if(key == 'tr' || key == 'as' || key == 'xs')
                value = decodeURIComponent(value);
            else if(key == 'dn')
                value = value.replace(/\+/g, ' ');
            if(key in params_obj){
                if(isArray(params_obj[key])){
                    params_obj[key].push(value);
                } else {
                    const temp = params_obj[key];
                    params_obj[key] = [temp, value];
                }
            } else
                params_obj[key] = value;
        }
        return params_obj;
    }

    return decode;
})();