import {isArray} from './utils';

export default (function(){
    let mpi = false;
    /**
     * @name encode
     * @desc Encodes an object as a Magnet URI
     * @param obj{Object}
     * @param multiParamIndexing{Boolean}
     * @returns {String}
     */
    function encode(obj, multiParamIndexing=false){
        const keys = Object.keys(obj);
        mpi = multiParamIndexing;
        let magnet_uri = 'magnet:?';
        keys.forEach((key, idx) => {
           magnet_uri += to_param(key, obj[key], idx == 0);
        });
        return magnet_uri;
    }

    /**
     * @name to_param
     * @param key
     * @param value
     * @param first
     * @param idx
     * @returns {String}
     * @private
     */
    function to_param(key, value, first, idx=null){
        if(isArray(value)){
            return value.reduce((acc, value, currentIndex) =>
                acc += to_param(key, value, (currentIndex == 0 && first), currentIndex+1)
            , '');
        } else {
            if(key == 'tr' || key == 'as' || key == 'xs')
                value = encodeURIComponent(value);
            else if(key == 'dn')
                value = value.replace(/\s/g, '+');
            return `${first ? '' : '&'}${key}${(idx && mpi) ? `.${idx}` : ''}=${value}`;
        }
    }

    return encode;
})();